pub fn scan_charc() -> u8Expand description
Get a character (whose size is 1 byte) from the serial. Zero will be returned if the data is not ready for reading.
pub fn scan_charc() -> u8Get a character (whose size is 1 byte) from the serial. Zero will be returned if the data is not ready for reading.